import { vonage } from './clientsdk-clientcore_js';
/**
 * The EmbeddedInfo type
 *
 * @property kind The kind property of EmbeddedInfo
 * @property memberId The memberId property of EmbeddedInfo
 * @property user The user property of EmbeddedInfo
 * @interface
 */
export type EmbeddedInfo = {
    kind: 'embeddedInfo';
} & vonage.EmbeddedInfoJS;
/**
 * The System type
 *
 * @property kind The kind property of System
 * @interface
 */
export type System = {
    kind: 'system';
} & typeof vonage.SystemJS;
/**
 * A From is a discriminated union of {@link EmbeddedInfo}, {@link System}
 */
export type From = EmbeddedInfo | System;
/**
 * The EphemeralConversationEvent type
 *
 * @property kind The kind property of EphemeralConversationEvent
 * @property timestamp The timestamp property of EphemeralConversationEvent
 * @property conversationId The conversationId property of EphemeralConversationEvent
 * @property from The {@link From} property of EphemeralConversationEvent
 * @property body The body property of EphemeralConversationEvent
 * @interface
 * @group Chat
 */
export type EphemeralConversationEvent = {
    kind: 'ephemeral';
    from: From;
} & vonage.EphemeralConversationEventJS;
/**
 * A NonPersistentConversationEvent is a {@link EphemeralConversationEvent}
 * @group Chat
 */
export type NonPersistentConversationEvent = EphemeralConversationEvent;
import { MessageAudioEventBody } from '../utils/ConversationEventBodies';
import { MessageFileEventBody } from '../utils/ConversationEventBodies';
import { MessageImageEventBody } from '../utils/ConversationEventBodies';
import { MessageLocationEventBody } from '../utils/ConversationEventBodies';
import { MessageTemplateEventBody } from '../utils/ConversationEventBodies';
import { MessageVCardEventBody } from '../utils/ConversationEventBodies';
import { MessageVideoEventBody } from '../utils/ConversationEventBodies';
/**
 * The CustomConversationEvent type
 *
 * @property kind The kind property of CustomConversationEvent
 * @property id The id property of CustomConversationEvent
 * @property timestamp The timestamp property of CustomConversationEvent
 * @property conversationId The conversationId property of CustomConversationEvent
 * @property from The {@link From} property of CustomConversationEvent
 * @property eventType The eventType property of CustomConversationEvent
 * @property body The body property of CustomConversationEvent
 * @interface
 * @group Chat
 */
export type CustomConversationEvent = {
    kind: 'custom';
    from: From;
} & vonage.CustomConversationEventJS;
/**
 * The EventDeleteConversationEvent type
 *
 * @property kind The kind property of EventDeleteConversationEvent
 * @property id The id property of EventDeleteConversationEvent
 * @property timestamp The timestamp property of EventDeleteConversationEvent
 * @property conversationId The conversationId property of EventDeleteConversationEvent
 * @property from The {@link From} property of EventDeleteConversationEvent
 * @property body The body property of EventDeleteConversationEvent
 * @interface
 * @group Chat
 */
export type EventDeleteConversationEvent = {
    kind: 'event:delete';
    from: From;
} & vonage.EventDeleteConversationEventJS;
/**
 * The MemberInvitedEvent type
 *
 * @property kind The kind property of MemberInvitedEvent
 * @property id The event id
 * @property timestamp The event timestamp
 * @property conversationId The conversation id
 * @property from The event sender
 * @property body The invited member
 * @interface
 * @group Chat
 */
export type MemberInvitedEvent = {
    kind: 'member:invited';
    from: From;
} & vonage.MemberInvitedEventJS;
/**
 * The MemberJoinedEvent type
 *
 * @property kind The kind property of MemberJoinedEvent
 * @property id The id property of MemberJoinedEvent
 * @property timestamp The timestamp property of MemberJoinedEvent
 * @property conversationId The conversationId property of MemberJoinedEvent
 * @property from The {@link From} property of MemberJoinedEvent
 * @property body The body property of MemberJoinedEvent
 * @interface
 * @group Chat
 */
export type MemberJoinedEvent = {
    kind: 'member:joined';
    from: From;
} & vonage.MemberJoinedEventJS;
/**
 * The MemberLeftEvent type
 *
 * @property kind The kind property of MemberLeftEvent
 * @property id The id property of MemberLeftEvent
 * @property timestamp The timestamp property of MemberLeftEvent
 * @property conversationId The conversationId property of MemberLeftEvent
 * @property from The {@link From} property of MemberLeftEvent
 * @property body The body property of MemberLeftEvent
 * @interface
 * @group Chat
 */
export type MemberLeftEvent = {
    kind: 'member:left';
    from: From;
} & vonage.MemberLeftEventJS;
/**
 * The MessageAudioEvent type
 *
 * @property kind The kind property of MessageAudioEvent
 * @property id The id property of MessageAudioEvent
 * @property timestamp The timestamp property of MessageAudioEvent
 * @property conversationId The conversationId property of MessageAudioEvent
 * @property from The {@link From} property of MessageAudioEvent
 * @property body The body property of MessageAudioEvent
 * @interface
 * @group Chat
 */
export type MessageAudioEvent = {
    kind: 'message:audio';
    from: From;
    body: MessageAudioEventBody;
} & vonage.MessageAudioEventJS;
/**
 * The MessageCustomEvent type
 *
 * @property kind The kind property of MessageCustomEvent
 * @property id The id property of MessageCustomEvent
 * @property timestamp The timestamp property of MessageCustomEvent
 * @property conversationId The conversationId property of MessageCustomEvent
 * @property from The {@link From} property of MessageCustomEvent
 * @property body The body property of MessageCustomEvent
 * @interface
 * @group Chat
 */
export type MessageCustomEvent = {
    kind: 'message:custom';
    from: From;
} & vonage.MessageCustomEventJS;
/**
 * The MessageFileEvent type
 *
 * @property kind The kind property of MessageFileEvent
 * @property id The id property of MessageFileEvent
 * @property timestamp The timestamp property of MessageFileEvent
 * @property conversationId The conversationId property of MessageFileEvent
 * @property from The {@link From} property of MessageFileEvent
 * @property body The body property of MessageFileEvent
 * @interface
 * @group Chat
 */
export type MessageFileEvent = {
    kind: 'message:file';
    from: From;
    body: MessageFileEventBody;
} & vonage.MessageFileEventJS;
/**
 * The MessageImageEvent type
 *
 * @property kind The kind property of MessageImageEvent
 * @property id The id property of MessageImageEvent
 * @property timestamp The timestamp property of MessageImageEvent
 * @property conversationId The conversationId property of MessageImageEvent
 * @property from The {@link From} property of MessageImageEvent
 * @property body The body property of MessageImageEvent
 * @interface
 * @group Chat
 */
export type MessageImageEvent = {
    kind: 'message:image';
    from: From;
    body: MessageImageEventBody;
} & vonage.MessageImageEventJS;
/**
 * The MessageLocationEvent type
 *
 * @property kind The kind property of MessageLocationEvent
 * @property id The id property of MessageLocationEvent
 * @property timestamp The timestamp property of MessageLocationEvent
 * @property conversationId The conversationId property of MessageLocationEvent
 * @property from The {@link From} property of MessageLocationEvent
 * @property body The body property of MessageLocationEvent
 * @interface
 * @group Chat
 */
export type MessageLocationEvent = {
    kind: 'message:location';
    from: From;
    body: MessageLocationEventBody;
} & vonage.MessageLocationEventJS;
/**
 * The MessageTemplateEvent type
 *
 * @property kind The kind property of MessageTemplateEvent
 * @property id The id property of MessageTemplateEvent
 * @property timestamp The timestamp property of MessageTemplateEvent
 * @property conversationId The conversationId property of MessageTemplateEvent
 * @property from The {@link From} property of MessageTemplateEvent
 * @property body The body property of MessageTemplateEvent
 * @interface
 * @group Chat
 */
export type MessageTemplateEvent = {
    kind: 'message:template';
    from: From;
    body: MessageTemplateEventBody;
} & vonage.MessageTemplateEventJS;
/**
 * The MessageTextEvent type
 *
 * @property kind The kind property of MessageTextEvent
 * @property id The id property of MessageTextEvent
 * @property timestamp The timestamp property of MessageTextEvent
 * @property conversationId The conversationId property of MessageTextEvent
 * @property from The {@link From} property of MessageTextEvent
 * @property body The body property of MessageTextEvent
 * @interface
 * @group Chat
 */
export type MessageTextEvent = {
    kind: 'message:text';
    from: From;
} & vonage.MessageTextEventJS;
/**
 * The MessageVCardEvent type
 *
 * @property kind The kind property of MessageVCardEvent
 * @property id The id property of MessageVCardEvent
 * @property timestamp The timestamp property of MessageVCardEvent
 * @property conversationId The conversationId property of MessageVCardEvent
 * @property from The {@link From} property of MessageVCardEvent
 * @property body The body property of MessageVCardEvent
 * @interface
 * @group Chat
 */
export type MessageVCardEvent = {
    kind: 'message:vcard';
    from: From;
    body: MessageVCardEventBody;
} & vonage.MessageVCardEventJS;
/**
 * The MessageVideoEvent type
 *
 * @property kind The kind property of MessageVideoEvent
 * @property id The id property of MessageVideoEvent
 * @property timestamp The timestamp property of MessageVideoEvent
 * @property conversationId The conversationId property of MessageVideoEvent
 * @property from The {@link From} property of MessageVideoEvent
 * @property body The body property of MessageVideoEvent
 * @interface
 * @group Chat
 */
export type MessageVideoEvent = {
    kind: 'message:video';
    from: From;
    body: MessageVideoEventBody;
} & vonage.MessageVideoEventJS;
/**
 * A PersistentConversationEvent is a discriminated union of {@link CustomConversationEvent}, {@link EventDeleteConversationEvent}, {@link MemberInvitedEvent}, {@link MemberJoinedEvent}, {@link MemberLeftEvent}, {@link MessageAudioEvent}, {@link MessageCustomEvent}, {@link MessageFileEvent}, {@link MessageImageEvent}, {@link MessageLocationEvent}, {@link MessageTemplateEvent}, {@link MessageTextEvent}, {@link MessageVCardEvent}, {@link MessageVideoEvent}
 * @group Chat
 */
export type PersistentConversationEvent = CustomConversationEvent | EventDeleteConversationEvent | MemberInvitedEvent | MemberJoinedEvent | MemberLeftEvent | MessageAudioEvent | MessageCustomEvent | MessageFileEvent | MessageImageEvent | MessageLocationEvent | MessageTemplateEvent | MessageTextEvent | MessageVCardEvent | MessageVideoEvent;
/**
 * A ConversationEvent is a union of {@link NonPersistentConversationEvent}, {@link PersistentConversationEvent}
 * @group Chat
 */
export type ConversationEvent = NonPersistentConversationEvent | PersistentConversationEvent;
/**
 * A ConversationState is a union of 'ACTIVE', 'INACTIVE', 'DELETED'
 */
export type ConversationState = 'ACTIVE' | 'INACTIVE' | 'DELETED';
/**
 * A MemberState is a union of 'INVITED', 'JOINED', 'LEFT', 'UNKNOWN'
 */
export type MemberState = 'INVITED' | 'JOINED' | 'LEFT' | 'UNKNOWN';
